<?php
/**
 * refresh Theme Customizer
 *
 * @package refresh
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
/**
 * A class to create a dropdown for all categories in your WordPress site
 */
 if ( ! class_exists( 'WP_Customize_Control' ) )
    return NULL;
 class refresh_Category_Dropdown_Custom_Control extends WP_Customize_Control
 {
    private $cats = false;

    public function __construct($manager, $id, $args = array(), $options = array())
    {
        $this->cats = get_categories($options);

        parent::__construct( $manager, $id, $args );
    }

    /**
     * Render the content of the category dropdown
     *
     * @return HTML
     */
    public function render_content()
       {
            if(!empty($this->cats))
            {
                ?>
                    <label>
                      <span class="customize-category-select-control"><?php echo esc_html( $this->label ); ?></span>
                      <select <?php $this->link(); ?>>
                           <?php
                                foreach ( $this->cats as $cat )
                                {
                                    printf('<option value="%s" %s>%s</option>', $cat->term_id, selected($this->value(), $cat->term_id, false), $cat->name);
                                }
                           ?>
                      </select>
                    </label>
                <?php
            }
       }
 } 
function refresh_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'blogname', array(
			'selector'        => '.site-title a',
			'render_callback' => 'refresh_customize_partial_blogname',
		) );
		$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
			'selector'        => '.site-description',
			'render_callback' => 'refresh_customize_partial_blogdescription',
		) );
	}
	
	// Theme important links started
   class refresh_Important_Links extends WP_Customize_Control {

      public $type = "refresh-important-links";

      public function render_content() {
      
		 echo '<ul><b>
			<li>' . esc_attr__( '* Fully Mobile Responsive', 'refresh' ) . '</li>
			<li>' . esc_attr__( '* Dedicated Option Panel', 'refresh' ) . '</li>
			<li>' . esc_attr__( '* Customize Theme Color', 'refresh' ) . '</li>
			<li>' . esc_attr__( '* WooCommerce & bbPress Support', 'refresh' ) . '</li>
			<li>' . esc_attr__( '* SEO Optimized', 'refresh' ) . '</li>
			<li>' . esc_attr__( '* Control Individual Meta Option like: Category, date, Author, Tags etc. ', 'refresh' ) . '</li>
			<li>' . esc_attr__( '* Full Support', 'refresh' ) . '</li>
			<li>' . esc_attr__( '* Google Fonts', 'refresh' ) . '</li>
			<li>' . esc_attr__( '* Theme Color Customization', 'refresh' ) . '</li>
			<li>' . esc_attr__( '* Custom CSS', 'refresh' ) . '</li>
			<li>' . esc_attr__( '* Website Layout', 'refresh' ) . '</li>
			<li>' . esc_attr__( '* Select Number of Columns', 'refresh' ) . '</li>
			<li>' . esc_attr__( '* Website Width Control', 'refresh' ) . '</li>
			</b></ul>
		 ';
         $important_links = array(
		 
            'theme-info' => array(
               'link' => esc_url('https://www.insertcart.com/product/refresh-wp-theme/'),
               'text' => __('ReFresh Pro', 'refresh'),
            ),
            'support' => array(
               'link' => esc_url('https://www.insertcart.com/contact-us/'),
               'text' => __('Contact us', 'refresh'),
            ),         
			'Documentation' => array(
               'link' => esc_url('https://www.insertcart.com/refresh-theme-documentation-setup-guide/'),
               'text' => __('Documentation', 'refresh'),
            ),			 
         );
         foreach ($important_links as $important_link) {
            echo '<p><a target="_blank" href="' . $important_link['link'] . '" >' . esc_attr($important_link['text']) . ' </a></p>';
         }
               }

   }
      $wp_customize->add_section('refresh_important_links', array(
      'priority' => 1,
      'title' => __('Upgrade to Pro', 'refresh'),
   ));

   $wp_customize->add_setting('refresh_important_links', array(
      'capability' => 'edit_theme_options',
      'sanitize_callback' => 'refresh_links_sanitize'
   ));

   $wp_customize->add_control(new refresh_Important_Links($wp_customize, 'important_links', array(
      'section' => 'refresh_important_links',
      'settings' => 'refresh_important_links'
   )));

//Categories

$cats = array();
foreach ( get_categories() as $categoriesi => $categoryy ){
    $cats[$categoryy->term_id] = $categoryy->name;
}

// News Ticker	
		
$wp_customize-> add_section('refresh_newsticker',
    array(
    	'title'			=> __('News Ticker','refresh'),
    	'description'	=> __('Control News Ticker options & settings.','refresh')
    	)
    );
    
	
$wp_customize->add_setting('refresh_newstickerenable',
    array(
			'default'			=> 'enable',
			'type'				=> 'theme_mod',
			'capability'		=> 'edit_theme_options',
			'sanitize_callback'	=> 'refresh_sanitize_select'
    )
);
	$wp_customize->add_control('refresh_newstickerenable',
    array(
        'type' => 'radio',
		'settings'   => 'refresh_newstickerenable',
        'section' => 'refresh_newsticker',
        'choices' => array(
            'enable' => __('Enable','refresh'),
            'disable' => __('Disable','refresh'),
        ) ));
	
	$wp_customize->add_setting('refresh_tickername',
	array(
		'default'		=> 'News Ticker',
		'sanitize_callback'	=> 'sanitize_text_field'
		
		)
	);
	
	$wp_customize->add_control('refresh_tickername',
	        array(
				'label'		=> __( 'Title', 'refresh' ),
	            'section'	=> 'refresh_newsticker',
	            'settings' 	=> 'refresh_tickername',
	            'type'		=> 'text'
	        )
	);

	$wp_customize->add_setting('refresh_tickernum',
	array(
		'default'		=> '5',
		'sanitize_callback'	=> 'sanitize_text_field'
		
		)
	);
	
	$wp_customize->add_control('refresh_tickernum',
	        array(
			'label'        => __( 'Number of Post to show. Default: 5', 'refresh' ),
	            'section' => 'refresh_newsticker',
	            'settings' => 'refresh_tickernum',
	            'type' => 'text'
	        )
	);

$wp_customize->add_setting( 'ticker_category', array(
    'default' => 1,
    'sanitize_callback' => 'absint'
) );
 
$wp_customize->add_control( 'cat_contlr_top', array(
	'label'        => __( 'Choose Category', 'refresh' ),
    'settings' => 'ticker_category',
    'type' => 'select',
    'choices' => $cats,
    'section' => 'refresh_newsticker',  // depending on where you want it to be
) );	
/**************************************************
* Social
***************************************************/
	// Social Icons
	$wp_customize->add_section('refresh_social_section', array(
			'title' => __('Social Icons','refresh'),
			'priority' => 4,
			//	'panel'	=> 'refresh_panel_advance'
	));
	
	$social_networks = array( //Redefinied in Sanitization Function.
					'none' => __('-','refresh'),
					'facebook' => __('Facebook','refresh'),
					'twitter' => __('Twitter','refresh'),
					'instagram' => __('Instagram','refresh'),
					'linkedin' => __('Linkedin','refresh'),
					'vine' => __('Vine','refresh'),
					'vimeo' => __('Vimeo','refresh'),
					'youtube' => __('Youtube','refresh'),
					'snapchat' => __('Snapchat','refresh'),
					'pinterest' => __('Pinterest','refresh'),
					'reddit' => __('Reddit','refresh'),
					'vk' => __('VK','refresh'),
					'tumblr' => __('Tumblr','refresh'),
					'flickr' => __('Flickr','refresh'),
				);
				
	$social_count = count($social_networks);
				
	for ($x = 1 ; $x <= ($social_count - 3) ; $x++) :
			
		$wp_customize->add_setting(
			'refresh_social_'.$x, array(
				'sanitize_callback' => 'refresh_sanitize_social',
				'default' => 'none'
			));

		$wp_customize->add_control( 'refresh_social_'.$x, array(
					'settings' => 'refresh_social_'.$x,
					'label' => __('Icon ','refresh').$x,
					'section' => 'refresh_social_section',
					'type' => 'select',
					'choices' => $social_networks,			
		));
		
		$wp_customize->add_setting(
			'refresh_social_url'.$x, array(
				'sanitize_callback' => 'esc_url_raw'
			));

		$wp_customize->add_control( 'refresh_social_url'.$x, array(
					'settings' => 'refresh_social_url'.$x,
					'description' => __('Icon ','refresh').$x.__(' Url','refresh'),
					'section' => 'refresh_social_section',
					'type' => 'url',
					'choices' => $social_networks,			
		));
		
	endfor;
	
	function refresh_sanitize_social( $input ) {
		$social_networks = array(
					'none' ,
					'facebook',
					'twitter',
					'instagram',
					'linkedin',
					'vine',
					'vimeo',
					'youtube',
					'snapchat',
					'pinterest',
					'reddit',
					'vk',
					'tumblr',
					'flickr'
				);
		if ( in_array($input, $social_networks) )
			return $input;
		else
			return '';	
	}	
	
	
	
}
add_action( 'customize_register', 'refresh_customize_register' );

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function refresh_customize_partial_blogname() {
	bloginfo( 'name' );
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function refresh_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function refresh_customize_preview_js() {
	wp_enqueue_script( 'refresh-customizer', get_template_directory_uri() . '/js/customizer.js', array( 'customize-preview' ), '20151215', true );
}
add_action( 'customize_preview_init', 'refresh_customize_preview_js' );

function refresh_sanitize_select( $input, $setting ) {
	
	// Ensure input is a slug.
	$input = sanitize_key( $input );
	
	// Get list of choices from the control associated with the setting.
	$choices = $setting->manager->get_control( $setting->id )->choices;
	
	// If the input is a valid key, return it; otherwise, return the default.
	return ( array_key_exists( $input, $choices ) ? $input : $setting->default );
}

function refresh_sanitize_image( $image, $setting ) {
	/*
	 * Array of valid image file types.
	 *
	 * The array includes image mime types that are included in wp_get_mime_types()
	 */
    $mimes = array(
        'jpg|jpeg|jpe' => 'image/jpeg',
        'gif'          => 'image/gif',
        'png'          => 'image/png',
        'bmp'          => 'image/bmp',
        'tif|tiff'     => 'image/tiff',
        'ico'          => 'image/x-icon'
    );
	// Return an array with file extension and mime_type.
    $file = wp_check_filetype( $image, $mimes );
	// If $image has a valid mime_type, return it; otherwise, return the default.
    return ( $file['ext'] ? $image : $setting->default );
}